#!/bin/sh -ex

scriptdir="$(realpath $(dirname "$0"))"
temp=/tmp/osmo-move-manuals

# Validate arguments
src="$1"
manual="$2"
repo="$3"
if [ "$#" != 3 ]; then
	echo "usage: $(basename $0) src-path manual-dir git-repo-name"
	exit 1
fi
if ! [ -d "$src/$repo" ]; then
	echo "ERROR: $src/$repo not found!"
	exit 1
fi
git -C "$src/osmo-gsm-manuals" checkout master
if ! [ -d "$src/osmo-gsm-manuals/$manual" ]; then
	echo "ERROR: $src/osmo-gsm-manuals/$manual not found!"
	exit 1
fi

# Set up temp dir
if [ -d "$temp" ]; then
	rm -rf "$temp"
fi
mkdir "$temp"

# Write filter script
cat <<EOF > "$temp/filter.sh"
#!/bin/sh -e

# Remove old $temp/all
if [ -d "$temp/all" ]; then
	rm -r "$temp/all"
fi

# Move all files to $temp/all
mkdir "$temp/all"
mv * "$temp/all"
rm .gitignore .gitreview 2> /dev/null || true

# Move the dir we care about to doc/manuals
if [ -d "$temp/all/$manual" ]; then
	mkdir doc
	mv "$temp/all/$manual" doc/manuals
fi
EOF

# Create a new branch and filter it
cd "$src/osmo-gsm-manuals"
git checkout master
git reset --hard origin/master
git branch -D "temp/move-manuals-$repo" 2> /dev/null || true
git checkout -b "temp/move-manuals-$repo"
git filter-branch -f --tree-filter "sh $temp/filter.sh" --prune-empty

# Merge into the project repo
cd "$src/$repo"
git remote remove osmo-gsm-manuals 2> /dev/null || true
git remote add -f osmo-gsm-manuals "$src/osmo-gsm-manuals"
git checkout master
git reset --hard origin/master
git merge "osmo-gsm-manuals/temp/move-manuals-$repo" --allow-unrelated-histories \
	-m "add manuals from osmo-gsm-manuals.git

Related: OS#3385"
git commit --amend --no-edit # add Change-Id

# Clean up
rm -rf "$temp"
cd "$src/osmo-gsm-manuals"
git checkout master
git branch -D "temp/move-manuals-$repo"
cd "$src/$repo"
git remote remove osmo-gsm-manuals
